@@ -18,7 +18,7 @@ BEGIN {
 
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-$VERSION   = '2.12_008';
+$VERSION   = '2.18_001';
 $VERSION   = eval $VERSION;
 @ISA       = qw(Exporter);
 @EXPORT    = qw(mkpath rmtree);
@@ -633,7 +633,7 @@ File::Path - Create or remove directory trees
 
 =head1 VERSION
 
-2.12_008 - released May 07 2017.
+2.18_001 - released November 4 2020.
 
 =head1 SYNOPSIS
 
@@ -774,17 +774,19 @@ identical to C<make_path()>.
 
 The C<remove_tree> function deletes the given directories and any
 files and subdirectories they might contain, much like the Unix
-command C<rm -rf> or the Windows commands C<rmdir /s> and C<rd /s>. The
-only exception to the function similarity is that C<remove_tree> accepts
-only directories whereas C<rm -rf> also accepts files.
+command C<rm -rf> or the Windows commands C<rmdir /s> and C<rd /s>.
 
-The function accepts a list of directories to be
-removed. Its behaviour may be tuned by an optional hashref
+The function accepts a list of directories to be removed. (In point of fact,
+it will also accept filesystem entries which are not directories, such as
+regular files and symlinks.  But, as its name suggests, its intent is to
+remove trees rather than individual files.)
+
+C<remove_tree()>'s behaviour may be tuned by an optional hashref
 appearing as the last parameter on the call.  If an empty string is
 passed to C<remove_tree>, an error will occur.
 
 B<NOTE:>  For security reasons, we strongly advise use of the
-hashref-as-final-argument syntax, specifically with a setting of the C<safe>
+hashref-as-final-argument syntax -- specifically, with a setting of the C<safe>
 element to a true value.
 
     remove_tree( $dir1, $dir2, ....,
@@ -969,9 +971,9 @@ problem mentioned in CVE-2002-0435.
 
 See the following pages for more information:
 
-  http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=286905
-  http://www.nntp.perl.org/group/perl.perl5.porters/2005/01/msg97623.html
-  http://www.debian.org/security/2005/dsa-696
+    http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=286905
+    http://www.nntp.perl.org/group/perl.perl5.porters/2005/01/msg97623.html
+    http://www.debian.org/security/2005/dsa-696
 
 Additionally, unless the C<safe> parameter is set (or the
 third parameter in the traditional interface is TRUE), should a
@@ -979,6 +981,27 @@ C<remove_tree> be interrupted, files that were originally in read-only
 mode may now have their permissions set to a read-write (or "delete
 OK") mode.
 
+The following CVE reports were previously filed against File-Path and are
+believed to have been addressed:
+
+=over 4
+
+=item * L<http://cve.circl.lu/cve/CVE-2004-0452>
+
+=item * L<http://cve.circl.lu/cve/CVE-2005-0448>
+
+=back
+
+In February 2017 the cPanel Security Team reported an additional vulnerability
+in File-Path.  The C<chmod()> logic to make directories traversable can be
+abused to set the mode on an attacker-chosen file to an attacker-chosen value.
+This is due to the time-of-check-to-time-of-use (TOCTTOU) race condition
+(L<https://en.wikipedia.org/wiki/Time_of_check_to_time_of_use>) between the
+C<stat()> that decides the inode is a directory and the C<chmod()> that tries
+to make it user-rwx.  CPAN versions 2.13 and later incorporate a patch
+provided by John Lightsey to address this problem.  This vulnerability has
+been reported as CVE-2017-6512.
+
 =head1 DIAGNOSTICS
 
 FATAL errors will cause the program to halt (C<croak>), since the
@@ -1223,7 +1246,7 @@ James (Jim) Keenan <F<jkeenan@cpan.org>>.
 
 =head1 CONTRIBUTORS
 
-Contributors to File::Path, in alphabetical order.
+Contributors to File::Path, in alphabetical order by first name.
 
 =over 1
 
@@ -1237,6 +1260,8 @@ Contributors to File::Path, in alphabetical order.
 
 =item John Lightsey <F<john@perlsec.org>>
 
+=item Nigel Horne <F<njh@bandsman.co.uk>>
+
 =item Richard Elberger <F<riche@cpan.org>>
 
 =item Ryan Yee <F<ryee@cpan.org>>
@@ -1252,7 +1277,7 @@ Contributors to File::Path, in alphabetical order.
 =head1 COPYRIGHT
 
 This module is copyright (C) Charles Bailey, Tim Bunce, David Landgren,
-James Keenan and Richard Elberger 1995-2017. All rights reserved.
+James Keenan and Richard Elberger 1995-2020. All rights reserved.
 
 =head1 LICENSE
 
